AppIconTemplate class

Constructors

AppIconTemplate({required Platform platform, required String directoryPath, required List<String>? imageDirectory, required Map<String, dynamic> sizes, String extension = 'png'})

Properties

directoryPath String
final
extension String
final
hashCode int
The hash code for this object.
no setterinherited
imageDirectory List<String>?
final
platform Platform
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizes Map<String, dynamic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited