ConsoleLog class

A utility class for printing colored and styled logs in terminal.

Constructors

ConsoleLog()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

error(String message) → void
Print an error message (red + bold)
info(String message) → void
Print a general info message (blue)
line() → void
Print a line separator
step(String message) → void
Print a subtle progress update (magenta)
success(String message) → void
Print a success message (green)
title(String message) → void
Print a section title or header (cyan + bold)
warning(String message) → void
Print a warning message (yellow)