InputPath class

Constructors

InputPath({required String? assets, required String? appIcon, required String? translationFile})
InputPath.fromYaml(dynamic yaml)
factory

Properties

appIcon String?
final
assets String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translationFile String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited