ProjectUtils class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

dartReservedKeywords Set<String>
final
fileGenerationString String
no setter
getPackageName String
no setter
getPackageVersion String
no setter

Static Methods

createKey(String input) String
getProjectName() String
Reads the project's pubspec.yaml from the current working directory and returns the top-level name value as a String.
showHelp() → void
toCamelCase(String text) String
Convert a string to camelCase
toPascalCase(String input) String
Convert a string to pascalCase