TranslationCache class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete({required String source}) Future<void>
get({required String source}) Future<Map<String, dynamic>?>
init() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsert({required String source, required Map<String, dynamic> translations}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance TranslationCache
final