VersionChecker class

A simple version checker for Dart CLI tools.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkForUpdates({bool showCurrentVersion = false}) Future<void>
Checks if a new version is available and prints a message.
isNewerVersion(String latest, String current) bool
Compares two semantic versions.