TranslationSystem class

Constructors

TranslationSystem({required String sourceLanguage, required List<String>? language, required String? inputDestination, required String? outputDestination, required String outputFileExtension, required bool? generateTranslationKeys, required String? translationKeysLocation})
TranslationSystem.fromYaml(dynamic yaml)
factory

Properties

generateTranslationKeys bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inputDestination String?
getter/setter pair
language List<String>?
getter/setter pair
outputDestination String?
getter/setter pair
outputFileExtension String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceLanguage String
getter/setter pair
translationKeysLocation String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited